import datetime
import time
from reportlab.lib.enums import TA_JUSTIFY,TA_LEFT
from reportlab.lib.pagesizes import letter
from reportlab.platypus import SimpleDocTemplate, Paragraph, Spacer, Image,PageBreak
from reportlab.lib.styles import getSampleStyleSheet, ParagraphStyle
from reportlab.lib.units import inch
from reportlab.platypus.tables import Table,TableStyle
from reportlab.lib import colors
from reportlab.pdfgen import canvas
from reportlab.lib.pagesizes import LETTER
import os



def instance_name(details):
    filename = details["sid"] + '_' + details["env"] + '_' +'%s' % details["run_at"] + '.pdf'
    save_path = os.path.join("/var/www/html/caremigration/", "static/", filename)
    doc = SimpleDocTemplate(save_path,pagesize=letter,
                        rightMargin=72,leftMargin=72,
                        topMargin=0,bottomMargin=84)
    doc.title = "Health Check Report"
    return doc


class FooterCanvas(canvas.Canvas):

    def __init__(self, *args, **kwargs):
        canvas.Canvas.__init__(self, *args, **kwargs)
        self.pages = []

    def showPage(self):
        self.pages.append(dict(self.__dict__))
        self._startPage()

    def save(self):
        page_count = len(self.pages)
        for page in self.pages:
            self.__dict__.update(page)
            self.draw_canvas(page_count)
            canvas.Canvas.showPage(self)
        canvas.Canvas.save(self)

    def draw_canvas(self, page_count):
        page = "©2021 Care4SAP. All rights Reserved. | Powered By Canopus GBS.                                                                Page %s of %s" % (self._pageNumber, page_count)
        x = 66
        self.saveState()
        self.setStrokeColorRGB(0, 0, 0)
        self.setLineWidth(0.5)
        self.line(66, 78, LETTER[0] - 66, 78)
        self.setFont('Times-Roman', 10)
        self.drawString(x, 65, page)
        self.restoreState()
styles=getSampleStyleSheet()
styles.add(ParagraphStyle(name='mainheading', leftIndent = 75,textColor= colors.black,fontSize = 28))
styles.add(ParagraphStyle(name='mainheading1', leftIndent = 175,textColor= colors.black,fontSize = 20))
styles.add(ParagraphStyle(name='mainheading2',backColor='#2766A8',borderPadding = (10,0,20,175),leftIndent = 175,textColor= colors.white,fontSize = 20))
styles.add(ParagraphStyle(name='heading', textColor= '#F0AB00',fontSize = 18))
styles.add(ParagraphStyle(name='subheading', textColor= colors.blue,fontSize = 13))

Story=[]
logo1 = "/var/www/html/caremigration/care4s_logo.png"
im1 = Image(logo1, 2*inch, 0.5*inch)
logo2 = "/var/www/html/caremigration/tata_logo.png"
im2 = Image(logo2, 1*inch, 0.5*inch)
chart_style = TableStyle([('ALIGN', (0, 0), (-1, -1), 'LEFT'),
                          ('VALIGN', (0, 0), (-1, -1), 'RIGHT')])
t = Table([[im1, im2]],
                     colWidths=[5 * inch, 1.8* inch],
                     style = chart_style)
 
Story.append(t) 
Story.append(Spacer(1, 30))                         
ptext = "SAP Health Check Report"
Story.append(Paragraph(ptext, styles["mainheading"]))
Story.append(Spacer(1, 60))
def instancegeneratepdf(details,output,doc):
    # styles.add(ParagraphStyle(name='Justify', alignment=TA_JUSTIFY))

    osinfo = [['OS Information']]
    try:
        osinfo.append(['Operating System',details["ostype"]])
    except:
        osinfo.append(['Server Name',''])
    
    try:
        osinfo.append(['Server Name',details["sysname"]])
    except:
        osinfo.append(['Server Name',''])

    try:
        osinfo.append(['Network Address',details["ip"]])
    except:
        osinfo.append(['Network Address',''])

    try:
        osinfo.append(['Release',details["osversion"]])
    except:
        osinfo.append(['Release',''])

    osinfotable=Table(osinfo)
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )

    osinfotable.setStyle(GRID_STYLE)
 

    dbinfo = [['DB Information','']]
    try:
        dbinfo.append(['DB System',details["dbtype"]])
    except:
        dbinfo.append(['DB System',''])
    
    try:
        dbinfo.append(['DB Version',details["dbversion"]])
    except:
        dbinfo.append(['DB Version',''])

    try:
        dbinfo.append(['System SID',details["sid"]])
    except:
        dbinfo.append(['System SID',''])
    
    try:
        dbinfo.append(['Environment',details["env"]])
    except:
        dbinfo.append(['Environment',''])

    dbinfotable=Table(dbinfo)
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )

    dbinfotable.setStyle(GRID_STYLE)

    data= [[osinfotable, dbinfotable]]
    t = Table(data, hAlign='LEFT')
    t.setStyle(TableStyle([
               ('VALIGN',(0,0),(-1,-1),'TOP')
               ]))
    Story.append(t) 
    Story.append(Spacer(1, 12)) 

    userinfo = [['Other Information','']]

    # try:
    #     userinfo.append(['Log Id',details["log_id"]])
    # except:
    #     userinfo.append(['Log Id',''])

    try:
        userinfo.append(['Status','Completed'])
    except:
        userinfo.append(['Status',''])

    try:
        userinfo.append(['Run By',details["run_by"]])
    except:
        userinfo.append(['Run By',''])

    try:
        userinfo.append(['Run At',details["run_at"]])
    except:
        userinfo.append(['Run At',''])

    userinfotable=Table(userinfo,hAlign='LEFT')
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )

    userinfotable.setStyle(GRID_STYLE)

    Story.append(userinfotable) 
    Story.append(Spacer(1, 12))

    healthcheckinfo = [['Health Check Program Details','', ''],['Solution','System','Health Check']]

    try:
        healthcheckinfo.append([details["sysname"].split('_')[1],details["sysname"],details["healthcheckName"]])
    except:
        try:
            healthcheckinfo.append(['',details["sysname"],details["healthcheckName"]])
        except:
            try:
                healthcheckinfo.append([details["sysname"].split('_')[1],'',details["healthcheckName"]])
            except:
                try:
                    healthcheckinfo.append([details["sysname"].split('_')[1],details["sysname"],''])
                except:
                    try:
                        healthcheckinfo.append(['','',details["healthcheckName"]])
                    except:
                        try:
                            healthcheckinfo.append([details["sysname"].split('_')[1],'',''])
                        except:
                            try:
                                healthcheckinfo.append(['',details["sysname"],''])     
                            except:
                                healthcheckinfo.append(['','',''])

    healthcheckinfotable=Table(healthcheckinfo,hAlign='LEFT')
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )

    healthcheckinfotable.setStyle(GRID_STYLE)

 
    Story.append(healthcheckinfotable) 
    Story.append(Spacer(1, 30)) 

    ptext = '<b><i>This report contains confidential customer data and may be viewed only by SAP DBS employees, authorized SAP partners, and customer employees. Do not distribute it to other parties.</i></b>'
    Story.append(Paragraph(ptext, styles["Normal"]))
    Story.append(Spacer(1, 12))
    Story.append(PageBreak())


    Story.append(Spacer(1, 12)) 
    ptext = "SUMMARY"
    Story.append(Paragraph(ptext, styles["mainheading2"]))
    Story.append(Spacer(1, 30)) 

    summary = [['Metrics','Status']]
    try:
        for i in output['responsetimes']:
            if  i['metric'] == 'ResponseTime':
                k = i['value'].split(' ')
                if int(k[0])<1000:
                    temp = ['Response Times','Green']
                    summary.append(temp)
                else:
                    temp = ['Response Times','Red']
                    summary.append(temp)                    
    except:
        summary.append(['Response Times','NA'])

    try:                    
        for i in output['runtimedumps']:
            if i['metric'] == 'Shortdumps Frequency':
                k = i['value'].split(' ')
                if int(k[0])==0:
                    temp = ['Runtime Dumps','Green']
                    summary.append(temp)
                else:
                    temp = ['Runtime Dumps','Red']
                    summary.append(temp)
    except:
        summary.append(['Runtime Dumps','NA']) 

    try:                   
        temp = []
        hitratiolist = []            
        for i in output['buffer']:
            
            if (i['metric'] == 'HitRatio'):
                hitratiolist.append([i['buffertype'],i['value']])
                k = i['value'].split(' ')
                if int(k[0])>90:
                     temp.append('green')
                else:
                    temp.append('red')
        if 'red' in temp:
            summary.append(['Buffer','Red'])
        else:
            summary.append(['Buffer','Green'])                
    except:
        summary.append(['Buffer','NA'])

    try:            
        for i in output['updatemonitoring']:
            if i['metric'] == 'ErrorsInWpUD1':
                if int(i['value'])==0:
                    temp = ['Update Monitoring','Green']
                    summary.append(temp)
                else:
                    temp = ['Update Monitoring','Red']
                    summary.append(temp)                              
    except:
        summary.append(['Update Monitoring','NA'])                              

    try:
        for i in output['memory']:
            if i['metric'] == 'Physical':
                total = int(i['value'].split(' ')[0])
            if i['metric'] == 'Free (Value)':
                free = int(i['value'].split(' ')[0])
        if int((free*100)/total)<5:
           summary.append(['Memory Utilization','Red'])
        else:
            summary.append(['Memory Utilization','Green'])        
    except:
        summary.append(['Memory Utilization','Green'])        

    try:            
        for i in output['cpu']:
            if i['metric'] == 'CPU_Utilization':
                used = int(i['value'].split(' ')[0])
        if used>80:
            summary.append(['CPU Utilization','Red'])
        else:
            summary.append(['CPU Utilization','Green'])                    
    except:
        summary.append(['CPU Utilization','NA'])                            

    try:    
        temp = []            
        for i in output['fs']:
            if int(i['perc'].split(' ')[0])>85:
                temp.append('red')
            else:
                temp.append('green')            

        if 'red' in temp:
            summary.append(['File System','Red'])
        else:
            summary.append(['File System','Green'])
    except:
        summary.append(['File System','NA'])
    
    t=Table(summary,hAlign='LEFT')
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    for row, values, in enumerate(summary):
        for column, value in enumerate(values):
            if value == "Red":
                GRID_STYLE.add('BACKGROUND', (column, row), (column, row), colors.red)
            if value == "Green":
                GRID_STYLE.add('BACKGROUND', (column, row), (column, row), colors.green)    

    t.setStyle(GRID_STYLE)
    Story.append(t)  
    Story.append(Spacer(1, 12))

    ptext = "Instance Status/Details"

    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    instancelist = [['Instance Name','Instance Number','Features','Port','Status']]
    for i in output['instances']:
        if int(i['status']) == 1:
            string = "All OK"
        if int(i['status'])==2:
            string ="Warning"
        if int(i['status']) == 0:
            string = "Error"
        temp = [i['instaname'],i['instanceno'],i['features'],i['http_port'],string]
        instancelist.append(temp)
    t=Table(instancelist,hAlign='LEFT')
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )

    for row, values, in enumerate(instancelist):
        for column, value in enumerate(values):
            if value == "All OK":
                GRID_STYLE.add('BACKGROUND', (column, row), (column, row), colors.green)
            if value == "Warning":
                GRID_STYLE.add('BACKGROUND', (column, row), (column, row), colors.yellow)
            if value == "Error":
                GRID_STYLE.add('BACKGROUND', (column, row), (column, row), colors.red)  

    t.setStyle(GRID_STYLE)
    t._argW[0]=1.36*inch
    t._argW[1]=1.36*inch
    t._argW[2]=2.08*inch
    t._argW[3]=1*inch
    t._argW[4]=1*inch
    Story.append(t)
    Story.append(Spacer(1, 12))


    ptext = "Monitoring Check List as on " + str(datetime.datetime.now().strftime("%Y-%m-%d %H:%M %p"))

    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    
    
    monitoringchecklistdata = [['Task','T-Code','Status/Observations','Errors/Comments']]

    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )

    try:
        instancesdict={}
        for i in range(len(output['instances'])):
            instancesdict[output['instances'][i]['instaname']] = output['instances'][i]['status']
        
        for i, j in instancesdict.items():
            if instancesdict[i] == '1':
                string = "All instances are active"
                GRID_STYLE.add('BACKGROUND', (2, 1), (2, 1), colors.green)
            else:
                string = "One or more instances might have errors"
                GRID_STYLE.add('BACKGROUND', (2, 1), (2, 1), colors.red)
        monitoringchecklistdata.append(['Application Servers','SM51',Paragraph(string, styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['Application Servers','SM51','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 1), (3, 1), colors.red)

    try:
        workprocessdict={}
        for i in range(len(output['workprocess'])):
            workprocessdict[output['workprocess'][i]['typ']] = workprocessdict.get(output['workprocess'][i]['typ'],0) + 1
        
        string = "<br />".join(str(key) + ': ' +str(value)+' (Total)' for key, value in workprocessdict.items())
        monitoringchecklistdata.append(['Systemwide Workstatus Process','SM50/SM51/SM66',Paragraph(string, styles['Normal']),''])
        GRID_STYLE.add('BACKGROUND', (2, 2), (2, 2), colors.green)
    except:
        monitoringchecklistdata.append(['Systemwide Workstatus Process','SM50/SM51/SM66','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 2), (3, 2), colors.red)
    try:
        usersloggedin={}
        for i in range(len(output['responsetimes'])):
            if output['responsetimes'][i]['metric'] == "UsersLoggedIn":
                usersloggedin[output['responsetimes'][i]['metric']]=output['responsetimes'][i]['value']
       
        string = usersloggedin['UsersLoggedIn']+' user sessions'
        monitoringchecklistdata.append(['No. of users logged in','AL08',Paragraph(string, styles['Normal']),''])
        GRID_STYLE.add('BACKGROUND', (2, 3), (2, 3), colors.green)
    except:
        monitoringchecklistdata.append(['No. of users logged in','AL08','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 3), (3, 3), colors.red)

    try:
        shortdumps={}
        for i in range(len(output['runtimedumps'])):
            if output['runtimedumps'][i]['metric'] == "Shortdumps Frequency":
                shortdumps[output['runtimedumps'][i]['metric']]=output['runtimedumps'][i]['value']
       

        if shortdumps['Shortdumps Frequency']=='0 /min':
            monitoringchecklistdata.append(['Total ABAP Dumps','ST22','Runtime Error: 0',''])
            GRID_STYLE.add('BACKGROUND', (2, 4), (2, 4), colors.green)
        else:
            string = 'Runtime Error: ' + shortdumps['Shortdumps Frequency']
            monitoringchecklistdata.append(['Total ABAP Dumps','ST22',Paragraph(string, styles['Normal']),''])
            GRID_STYLE.add('BACKGROUND', (2, 4), (2, 4), colors.red)
    except:
        monitoringchecklistdata.append(['Total ABAP Dumps','ST22','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 4), (3, 4), colors.red)

    try:
        errorsinupdate={}
        for i in range(len(output['updatemonitoring'])):
            if output['updatemonitoring'][i]['metric'] == "ErrorsInWpUD1" or output['updatemonitoring'][i]['metric'] == "ErrorsInWpUD2":
                errorsinupdate[output['updatemonitoring'][i]['metric']]= int(output['updatemonitoring'][i]['value'])
       

        if errorsinupdate['ErrorsInWpUD1']==0 and errorsinupdate['ErrorsInWpUD2']==0:
            monitoringchecklistdata.append(['Update Failures','SM13','Update Errors: 0',''])
            GRID_STYLE.add('BACKGROUND', (2, 5), (2, 5), colors.green)
        else:
            string = 'ErrorsInWpUD1: ' + str(errorsinupdate['ErrorsInWpUD1']) + '<br />' +'ErrorsInWpUD2: ' + str(errorsinupdate['ErrorsInWpUD2'])
            monitoringchecklistdata.append(['Update Failures','SM13',Paragraph(string, styles['Normal']),''])
            GRID_STYLE.add('BACKGROUND', (2, 5), (2, 5), colors.red)
    except:
        monitoringchecklistdata.append(['Update Failures','SM13','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 5), (3, 5), colors.red)

    try:
        string = 'Total Locks: ' + str(details['enquelockcount']) + '<br />' +'>1 Day Old Locks: ' + str(details['enquelocktimecount'])
        monitoringchecklistdata.append(['Enque Locks','SM12',Paragraph(string, styles['Normal']),''])
        if int(details['enquelocktimecount']) > 0:
            GRID_STYLE.add('BACKGROUND', (2, 6), (2, 6), colors.red)
        else:
            GRID_STYLE.add('BACKGROUND', (2, 6), (2, 6), colors.green)
    except:
         monitoringchecklistdata.append(['Enque Locks','SM12','','Error in retrieving details'])
         GRID_STYLE.add('BACKGROUND', (3, 6), (3, 6), colors.red)
    try:
        # monitoringchecklistdata.append(['System Log Check','SM21','demo',''])
        # error = [i['client']+','+ i['user']+','+ i['severity'] for i in details['abaplogs'] if i['severity'] != 'SAPControl-GREEN']
        error=[]
        if len(error)>0:
            string = '<br />'.join(error)
            GRID_STYLE.add('BACKGROUND', (2, 7), (2, 7), colors.red)
        else:
            string = 'All OK'
            GRID_STYLE.add('BACKGROUND', (2, 7), (2, 7), colors.green)

        monitoringchecklistdata.append(['System Log Check','SM21',Paragraph(string, styles['Normal']),''])

    except:
        monitoringchecklistdata.append(['System Log Check','SM21','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 7), (3, 7), colors.red)

    try:
        string = ''
        for i in hitratiolist:
            string = string + i[0] + ' - ' + i[1] + '<br />'
            if all([int(i[1].split(' ')[0]) > 90 for i in hitratiolist]):
                GRID_STYLE.add('BACKGROUND', (2, 8), (2, 8), colors.green)
            else:
                GRID_STYLE.add('BACKGROUND', (2, 8), (2, 8), colors.red)
        monitoringchecklistdata.append(['Checking SAP Buffer Quality','ST02',Paragraph(string, styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['Checking SAP Buffer Quality','ST02','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 8), (3, 8), colors.red)

    try:
        for i in details['databasebackup']:
            if i['ENTRY_TYPE_NAME'] == 'complete data backup':
                string = 'entry id - ' + i['ENTRY_ID'] + '<br />' + 'backup id - ' + i['BACKUP_ID'] + '<br />' + 'state - ' + i['STATE_NAME']
                if i['STATE_NAME'] == 'successful':
                    GRID_STYLE.add('BACKGROUND', (2, 9), (2, 9), colors.green)
                else:
                    GRID_STYLE.add('BACKGROUND', (2, 9), (2, 9), colors.red)
        monitoringchecklistdata.append(['DataBase Backup (Data Backup)','DB12',Paragraph(string, styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['DataBase Backup (Data Backup)','DB12','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 9), (3, 9), colors.red)

    try:
        for i in details['databasebackup']:
            if i['ENTRY_TYPE_NAME'] == 'log backup':
                string = 'entry id - ' + i['ENTRY_ID'] + '<br />' + 'backup id - ' + i['BACKUP_ID'] + '<br />' + 'state - ' + i['STATE_NAME']
                if i['STATE_NAME'] == 'successful':
                    GRID_STYLE.add('BACKGROUND', (2, 10), (2, 10), colors.green)
                else:
                    GRID_STYLE.add('BACKGROUND', (2, 10), (2, 10), colors.red)
        monitoringchecklistdata.append(['DataBase Backup (Data Backup)','DB12',Paragraph(string, styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['DataBase Backup (Data Backup)','DB12','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 10), (3, 10), colors.red)

    try:
        string = ''
        for i in output['cpu']:
            if i['metric'] == 'CPU_Utilization':
                string = string + 'CPU Utilization - ' + i['value']
                if int(i['value'].split(' ')[0]) > 90:
                    GRID_STYLE.add('BACKGROUND', (2, 11), (2, 11), colors.red)
                else:
                    GRID_STYLE.add('BACKGROUND', (2, 11), (2, 11), colors.green)

        monitoringchecklistdata.append(['CPU Utilization per Server','ST06',Paragraph(string, styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['CPU Utilization per Server','ST06','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 11), (3, 11), colors.red)

    try:
        string = []
        for i in output['memory']:
            if i['metric'] == 'Physical':
                string.append('Physical Memory: '+i['value'])
                total = int(i['value'].split(' ')[0])
            if i['metric'] == 'Free (Value)':
                string.append('Free Memory: '+i['value'])
                free = int(i['value'].split(' ')[0])
            if i['metric'] == 'Swap Free':
                string.append('Free Swap Size: '+i['value'])
            if i['metric'] == 'Swap Size':
                string.append('Actual Swap Size: '+i['value'])
        if int((free*100)/total)<5:
            GRID_STYLE.add('BACKGROUND', (2, 12), (2, 12), colors.red)
        else:
            GRID_STYLE.add('BACKGROUND', (2, 12), (2, 12), colors.green)

        monitoringchecklistdata.append(['Review system logs for problems.',Paragraph('ST06<br />(Memory utilisation per)',styles['Normal']),Paragraph('<br />'.join(string), styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['Review system logs for problems.',Paragraph('ST06<br />(Memory utilisation per)',styles['Normal']),'','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 12), (3, 12), colors.red)

    try:
        for i in output['responsetimes']:
            if  i['metric'] == 'ResponseTime':
                string = i['value']
                k = i['value'].split(' ')
                if int(k[0])<1000:
                    GRID_STYLE.add('BACKGROUND', (2, 13), (2, 13), colors.green)
                    GRID_STYLE.add('BACKGROUND', (2, 14), (2, 14), colors.green)
                    GRID_STYLE.add('BACKGROUND', (2, 15), (2, 15), colors.green)
                else:
                    GRID_STYLE.add('BACKGROUND', (2, 13), (2, 13), colors.red)
                    GRID_STYLE.add('BACKGROUND', (2, 14), (2, 14), colors.red)
                    GRID_STYLE.add('BACKGROUND', (2, 15), (2, 15), colors.red)

        monitoringchecklistdata.append(['Database Time','ST03N (Total)',Paragraph(string, styles['Normal']),''])
        monitoringchecklistdata.append(['Processing Time','ST03N (Total)',Paragraph(string, styles['Normal']),''])
        monitoringchecklistdata.append(['Avg. Response Time','ST03N (Total)',Paragraph(string, styles['Normal']),''])
    except:
        monitoringchecklistdata.append(['Database Time','ST03N (Total)','','Error in retrieving details'])
        monitoringchecklistdata.append(['Processing Time','ST03N (Total)','','Error in retrieving details'])
        monitoringchecklistdata.append(['Avg. Response Time','ST03N (Total)','','Error in retrieving details'])
        GRID_STYLE.add('BACKGROUND', (3, 11), (3, 11), colors.red)
        GRID_STYLE.add('BACKGROUND', (3, 12), (3, 12), colors.red)
        GRID_STYLE.add('BACKGROUND', (3, 13), (3, 13), colors.red)

    monitoringchecklisttable=Table(monitoringchecklistdata,hAlign='LEFT')

    monitoringchecklisttable.setStyle(GRID_STYLE)
    monitoringchecklisttable._argW[2]=2.08*inch

    Story.append(monitoringchecklisttable) 
    Story.append(Spacer(1, 12)) 

    Story.append(PageBreak())
    

    
    # ptext = "1.2 HANA Alerts"
    # Story.append(Paragraph(ptext, styles["subheading"]))    
    # Story.append(Spacer(1, 12)) 
    # hanaalertslist = [['Alert Id','Timestamp','Details']]
    # for i in output['hanadbalerts']:
    #     temp = [i['alert_id'],i['alert_timestamp'],Paragraph(i['alert_details'],
    #           styles['Normal'])]
    #     hanaalertslist.append(temp)

    # t=Table(hanaalertslist)
    # GRID_STYLE = TableStyle(
    #     [

    #         ('GRID',(0,0),(-1,-1),0.5,colors.black),
    #         ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
    #         ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

    #     ]
    # )
    # t.setStyle(GRID_STYLE) 
    # t._argW[0]=0.7*inch
    # t._argW[1]=2.3*inch
    # t._argW[2]=3.8*inch   
    # Story.append(t)
    # Story.append(Spacer(1, 12))

    ptext = "1 Application"
    Story.append(Paragraph(ptext, styles["heading"]))
    Story.append(Spacer(1, 12)) 


    ptext = "1.1 Workprocess"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    wplist = [['Instance','No','Typ','Start','CPU']]
    for i in output['workprocess']:
        temp = [i['instance'],i['no'],i['typ'],i['start'],i['cpu']]
        wplist.append(temp)
    t=Table(wplist)
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)
    t._argW[0]=1.39*inch
    t._argW[1]=1*inch
    t._argW[2]=1*inch
    t._argW[3]=1.13*inch
    t._argW[4]=1.13*inch
    Story.append(t)
    Story.append(Spacer(1, 12))

    ptext = "1.2 Response Times"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    responsetimeslist = [['Response Time','value']]
    for i in output['responsetimes']:
        temp = [i['metric'],Paragraph(i['value'],
              styles['Normal'])]
        responsetimeslist.append(temp)
    t=Table(responsetimeslist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12))

    ptext = "1.3 Runtime Dumps"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    runtimedumpslist = [['Dumps','value']]
    for i in output['runtimedumps']:
        temp = [i['metric'],Paragraph(i['value'],
              styles['Normal'])]
        runtimedumpslist.append(temp)
    t=Table(runtimedumpslist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12))

    ptext = "1.4 Buffer"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    bufferlist = [['Buffer Type','metric','value']]
    for i in output['buffer']:
        temp = [i['buffertype'],i['metric'],Paragraph(i['value'],
              styles['Normal'])]
        bufferlist.append(temp)
    t=Table(bufferlist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12))

    ptext = "1.5 Update"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    updatemonitoringlist = [['Update Type Type','metric','value']]
    for i in output['updatemonitoring']:
        temp = [i['updatetype'],i['metric'],Paragraph(i['value'],
              styles['Normal'])]
        updatemonitoringlist.append(temp)
    t=Table(updatemonitoringlist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12))

    ptext = "2 OS"
    Story.append(Paragraph(ptext, styles["heading"]))
    Story.append(Spacer(1, 12)) 
    ptext = "2.1 Memory"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    memlist = [['Type of memory','value']]
    for i in output['memory']:
        temp = [i['metric'],i['value']]
        memlist.append(temp)
    t=Table(memlist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12))

    ptext = "2.2 CPU"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    cpulist = [['Type of CPU','value']]
    for i in output['cpu']:
        temp = [i['metric'],i['value']]
        cpulist.append(temp)
    t=Table(cpulist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12)) 

    ptext = "2.3 File System"
    Story.append(Paragraph(ptext, styles["subheading"]))    
    Story.append(Spacer(1, 12))    


    fslist = [['File System','Available','Use %']]
    for i in output['fs']:
        temp = [i['filesys'],i['free'],i['perc']]
        fslist.append(temp)
    t=Table(fslist,hAlign="LEFT")
    GRID_STYLE = TableStyle(
        [

            ('GRID',(0,0),(-1,-1),0.5,colors.black),
            ('BACKGROUND', (0, 0), (-1, 0), '#2766A8'),
            ('TEXTCOLOR', (0, 0), (-1, 0), colors.white),

        ]
    )
    t.setStyle(GRID_STYLE)

    Story.append(t)
    Story.append(Spacer(1, 12)) 
    #doc.multiBuild(Story, canvasmaker=FooterCanvas)
    doc.build(Story)	